export declare function httpFetch({ url, method, json, headers, }: {
    method: string;
    json: unknown;
    headers?: Record<string, string>;
    url: string;
}): Promise<unknown>;
//# sourceMappingURL=http.d.ts.map