/**
 * Licensed to Apache Software Foundation (ASF) under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Apache Software Foundation (ASF) licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import type { Group, ResourceMetadata } from './types.js';
/**
 * BanyanDBClient wraps the BanyanDB HTTP client for executing queries.
 * Uses the HTTP API (grpc-gateway) instead of gRPC to avoid proto dependency issues.
 */
export declare class BanyanDBClient {
    private baseUrl;
    constructor(address: string);
    private static buildBaseUrl;
    /**
     * Execute a BydbQL query and return the result as a formatted string.
     */
    query(bydbqlQuery: string): Promise<string>;
    /**
     * Format the query response into a readable string.
     */
    private formatResponse;
    /**
     * List all groups.
     */
    listGroups(): Promise<Group[]>;
    /**
     * List streams in a group.
     */
    listStreams(group: string): Promise<ResourceMetadata[]>;
    /**
     * List measures in a group.
     */
    listMeasures(group: string): Promise<ResourceMetadata[]>;
    /**
     * List traces in a group.
     */
    listTraces(group: string): Promise<ResourceMetadata[]>;
    /**
     * List properties in a group.
     */
    listProperties(group: string): Promise<ResourceMetadata[]>;
    /**
     * List topN aggregations in a group.
     */
    listTopN(group: string): Promise<ResourceMetadata[]>;
    /**
     * List index rules in a group.
     */
    listIndexRule(group: string): Promise<ResourceMetadata[]>;
    /**
     * Create a group using JSON format.
     */
    createGroup(groupJson: string): Promise<string>;
}
export type { ResourceMetadata } from './types.js';
//# sourceMappingURL=index.d.ts.map