/**
 * Licensed to Apache Software Foundation (ASF) under one or more contributor
 * license agreements. See the NOTICE file distributed with this work for
 * additional information regarding copyright ownership. Apache Software
 * Foundation (ASF) licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export declare const BANYANDB_ADDRESS: string;
export declare const TRANSPORT: string;
export declare const MCP_HOST: string;
export declare const MCP_AUTH_TOKEN: string;
export declare const MCP_PORT: number;
export declare const MCP_MAX_BODY_BYTES: number;
export declare const MAX_ERROR_MESSAGE_LENGTH = 1024;
export declare const MAX_TOOL_RESPONSE_LENGTH: number;
export declare const MCP_RATE_LIMIT_WINDOW_MS: number;
export declare const MCP_RATE_LIMIT_MAX_REQUESTS: number;
export declare const MCP_RATE_LIMIT_MAX_CLIENTS: number;
//# sourceMappingURL=config.d.ts.map