/**
 * Licensed to Apache Software Foundation (ASF) under one or more contributor
 * license agreements. See the NOTICE file distributed with this work for
 * additional information regarding copyright ownership. Apache Software
 * Foundation (ASF) licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
declare const allowedResourceTypes: readonly ["groups", "streams", "measures", "traces", "properties"];
export type QueryHints = {
    description?: string;
    BydbQL?: string;
    resource_type?: string;
    resource_name?: string;
    group?: string;
};
export type ListGroupsArgs = {
    resourceType: (typeof allowedResourceTypes)[number];
    group?: string;
};
export declare function normalizeQueryHints(args: unknown): QueryHints;
export declare function validateListGroupsArgs(args: unknown): ListGroupsArgs;
export declare function validateQueryHints(queryHints: QueryHints): QueryHints;
export {};
//# sourceMappingURL=validation.d.ts.map